@@ -9,11 +9,11 @@ import importlib
 import inspect
 import pkgutil
 import re
-import warnings
 from functools import lru_cache
 from itertools import chain
+from operator import attrgetter
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Set, Union
+from typing import Any, Dict, List, Mapping, Optional, Set, Tuple, Union
 
 from pytkdocs.objects import Attribute, Class, Function, Method, Module, Object, Source
 from pytkdocs.parsers.attributes import get_class_attributes, get_instance_attributes, get_module_attributes, merge
@@ -173,6 +173,18 @@ class ObjectNode:
         function_type = type(lambda: None)
         return self.parent_is_class() and isinstance(self.obj, function_type)
 
+    def is_method_descriptor(self) -> bool:
+        """
+        Tell if this node's object is a method descriptor.
+
+        Built-in methods (e.g. those implemented in C/Rust) are often
+        method descriptors, rather than normal methods.
+
+        Returns:
+            If this node's object is a method descriptor.
+        """
+        return inspect.ismethoddescriptor(self.obj)
+
     def is_staticmethod(self) -> bool:
         """
         Tell if this node's object is a staticmethod.
@@ -323,16 +335,6 @@ class Loader:
         self.select_inherited_members = inherited_members
         self.new_path_syntax = new_path_syntax
 
-        if not new_path_syntax:
-            warnings.warn(
-                "With pytkdocs v0.9, the 'new_path_syntax` option was introduced. "
-                "The default value is False, but will become True in v0.11, "
-                "and the option will be removed in v0.13. "
-                "Please update your paths to use a colon to delimit modules from other objects. "
-                "Read more at https://pawamoy.github.io/pytkdocs/#details-on-new_path_syntax",
-                PendingDeprecationWarning,
-            )
-
     def get_object_documentation(self, dotted_path: str, members: Optional[Union[Set[str], bool]] = None) -> Object:
         """
         Get the documentation for an object and its children.
@@ -360,6 +362,8 @@ class Loader:
             root_object = self.get_staticmethod_documentation(leaf)
         elif leaf.is_classmethod():
             root_object = self.get_classmethod_documentation(leaf)
+        elif leaf.is_method_descriptor():
+            root_object = self.get_regular_method_documentation(leaf)
         elif leaf.is_method():
             root_object = self.get_regular_method_documentation(leaf)
         elif leaf.is_function():
@@ -395,7 +399,6 @@ class Loader:
             try:
                 code = Path(node.file_path).read_text()
             except (OSError, UnicodeDecodeError):
-                self.errors.append(f"Couldn't read source for '{path}': {error}")
                 source = None
             else:
                 source = Source(code, 1) if code else None
@@ -419,9 +422,9 @@ class Loader:
         for member_name, member in inspect.getmembers(module):
             if self.select(member_name, select_members):  # type: ignore
                 child_node = ObjectNode(member, member_name, parent=node)
-                if child_node.is_class() and node.root.obj is inspect.getmodule(member):
+                if child_node.is_class() and node.root.obj is inspect.getmodule(child_node.obj):
                     root_object.add_child(self.get_class_documentation(child_node))
-                elif child_node.is_function() and node.root.obj is inspect.getmodule(member):
+                elif child_node.is_function() and node.root.obj is inspect.getmodule(child_node.obj):
                     root_object.add_child(self.get_function_documentation(child_node))
                 elif member_name in attributes_data:
                     root_object.add_child(self.get_attribute_documentation(child_node, attributes_data[member_name]))
@@ -434,6 +437,15 @@ class Loader:
 
         return root_object
 
+    @staticmethod
+    def _class_path(cls):
+        mod = cls.__module__
+        qname = cls.__qualname__
+        if mod == "builtins":
+            return qname
+        else:
+            return f"{mod}.{qname}"
+
     def get_class_documentation(self, node: ObjectNode, select_members=None) -> Class:
         """
         Get the documentation for a class and its children.
@@ -447,7 +459,23 @@ class Loader:
         """
         class_ = node.obj
         docstring = inspect.cleandoc(class_.__doc__ or "")
-        root_object = Class(name=node.name, path=node.dotted_path, file_path=node.file_path, docstring=docstring)
+        bases = [self._class_path(b) for b in class_.__bases__]
+
+        source: Optional[Source]
+
+        try:
+            source = Source(*inspect.getsourcelines(node.obj))
+        except (OSError, TypeError) as error:
+            source = None
+
+        root_object = Class(
+            name=node.name,
+            path=node.dotted_path,
+            file_path=node.file_path,
+            docstring=docstring,
+            bases=bases,
+            source=source,
+        )
 
         # Even if we don't select members, we want to correctly parse the docstring
         attributes_data: Dict[str, Dict[str, Any]] = {}
@@ -460,7 +488,7 @@ class Loader:
                 context["signature"] = inspect.signature(class_.__init__)
             except (TypeError, ValueError):
                 pass
-        root_object.parse_docstring(self.docstring_parser, attributes=attributes_data)
+        root_object.parse_docstring(self.docstring_parser, **context)
 
         if select_members is False:
             return root_object
@@ -508,6 +536,7 @@ class Loader:
         for attr_name, properties, add_method in (
             ("__fields__", ["pydantic-model"], self.get_pydantic_field_documentation),
             ("_declared_fields", ["marshmallow-model"], self.get_marshmallow_field_documentation),
+            ("_meta.get_fields", ["django-model"], self.get_django_field_documentation),
             ("__dataclass_fields__", ["dataclass"], self.get_annotated_dataclass_field),
         ):
             if self.detect_field_model(attr_name, direct_members, all_members):
@@ -530,14 +559,24 @@ class Loader:
         Detect if an attribute is present in members.
 
         Arguments:
-            attr_name: The name of the attribute to detect.
+            attr_name: The name of the attribute to detect, can contain dots.
             direct_members: The direct members of the class.
             all_members: All members of the class.
 
         Returns:
             Whether the attribute is present.
         """
-        return attr_name in direct_members or (self.select_inherited_members and attr_name in all_members)
+
+        first_order_attr_name, remainder = split_attr_name(attr_name)
+        if not (
+            first_order_attr_name in direct_members
+            or (self.select_inherited_members and first_order_attr_name in all_members)
+        ):
+            return False
+
+        if remainder and not attrgetter(remainder)(all_members[first_order_attr_name]):
+            return False
+        return True
 
     def add_fields(
         self,
@@ -561,7 +600,10 @@ class Loader:
             base_class: The class declaring the fields.
             add_method: The method to add the children object.
         """
-        for field_name, field in members[attr_name].items():
+
+        fields = get_fields(attr_name, members=members)
+
+        for field_name, field in fields.items():
             select_field = self.select(field_name, select_members)  # type: ignore
             is_inherited = field_is_inherited(field_name, attr_name, base_class)
 
@@ -587,13 +629,11 @@ class Loader:
         try:
             signature = inspect.signature(function)
         except TypeError as error:
-            self.errors.append(f"Couldn't get signature for '{path}': {error}")
             signature = None
 
         try:
             source = Source(*inspect.getsourcelines(function))
         except OSError as error:
-            self.errors.append(f"Couldn't read source for '{path}': {error}")
             source = None
 
         properties: List[str] = []
@@ -636,7 +676,6 @@ class Loader:
         try:
             signature = inspect.signature(sig_source_func)
         except (TypeError, ValueError) as error:
-            self.errors.append(f"Couldn't get signature for '{path}': {error}")
             attr_type = None
         else:
             attr_type = signature.return_annotation
@@ -644,7 +683,6 @@ class Loader:
         try:
             source = Source(*inspect.getsourcelines(sig_source_func))
         except (OSError, TypeError) as error:
-            self.errors.append(f"Couldn't get source for '{path}': {error}")
             source = None
 
         return Attribute(
@@ -683,6 +721,35 @@ class Loader:
             properties=properties,
         )
 
+    @staticmethod
+    def get_django_field_documentation(node: ObjectNode) -> Attribute:
+        """
+        Get the documentation for a Django Field.
+
+        Arguments:
+            node: The node representing the Field and its parents.
+
+        Returns:
+            The documented attribute object.
+        """
+        prop = node.obj
+        path = node.dotted_path
+        properties = ["django-field"]
+
+        if prop.null:
+            properties.append("nullable")
+        if prop.blank:
+            properties.append("blank")
+
+        return Attribute(
+            name=node.name,
+            path=path,
+            file_path=node.file_path,
+            docstring=prop.verbose_name,
+            attr_type=prop.__class__,
+            properties=properties,
+        )
+
     @staticmethod
     def get_marshmallow_field_documentation(node: ObjectNode) -> Attribute:
         """
@@ -792,7 +859,7 @@ class Loader:
 
     def get_method_documentation(self, node: ObjectNode, properties: Optional[List[str]] = None) -> Method:
         """
-        Get the documentation for a method.
+        Get the documentation for a method or method descriptor.
 
         Arguments:
             node: The node representing the method and its parents.
@@ -803,12 +870,12 @@ class Loader:
         """
         method = node.obj
         path = node.dotted_path
+        signature: Optional[inspect.Signature]
         source: Optional[Source]
 
         try:
             source = Source(*inspect.getsourcelines(method))
         except OSError as error:
-            self.errors.append(f"Couldn't read source for '{path}': {error}")
             source = None
         except TypeError:
             source = None
@@ -819,12 +886,22 @@ class Loader:
             else:
                 properties.append("async")
 
+        try:
+            # for "built-in" functions, e.g. those implemented in C,
+            # inspect.signature() uses the __text_signature__ attribute, which
+            # provides a limited but still useful amount of signature information.
+            # "built-in" functions with no __text_signature__ will
+            # raise a ValueError().
+            signature = inspect.signature(method)
+        except ValueError as error:
+            signature = None
+
         return Method(
             name=node.name,
             path=path,
             file_path=node.file_path,
             docstring=inspect.getdoc(method),
-            signature=inspect.signature(method),
+            signature=signature,
             properties=properties or [],
             source=source,
         )
@@ -913,3 +990,39 @@ def field_is_inherited(field_name: str, fields_name: str, base_class: type) -> b
             *(getattr(parent_class, fields_name, {}).keys() for parent_class in base_class.__mro__[1:-1]),
         ),
     )
+
+
+def split_attr_name(attr_name: str) -> Tuple[str, Optional[str]]:
+    """
+    Split an attribute name into a first-order attribute name and remainder.
+
+    Args:
+        attr_name: Attribute name (a)
+
+    Returns:
+        Tuple containing:
+            first_order_attr_name: Name of the first order attribute (a)
+            remainder: The remainder (b.c)
+
+    """
+    first_order_attr_name, *remaining = attr_name.split(".", maxsplit=1)
+    remainder = remaining[0] if remaining else None
+    return first_order_attr_name, remainder
+
+
+def get_fields(attr_name: str, *, members: Mapping[str, Any] = None, class_obj=None) -> Dict[str, Any]:
+    if not (bool(members) ^ bool(class_obj)):
+        raise ValueError("Either members or class_obj is required.")
+    first_order_attr_name, remainder = split_attr_name(attr_name)
+    fields = members[first_order_attr_name] if members else dict(vars(class_obj)).get(first_order_attr_name, {})
+    if remainder:
+        fields = attrgetter(remainder)(fields)
+
+    if callable(fields):
+        fields = fields()
+
+    if not isinstance(fields, dict):
+        # Support Django models
+        fields = {getattr(f, "name", str(f)): f for f in fields if not getattr(f, "auto_created", False)}
+
+    return fields
